<html>
<head>
  <title><?echo $page->get('title-prefix') . $page->title ?></title>
  <link rel="stylesheet" type="text/css" title="default" href="<?=$root?>/?a=style&d=<?=$page->get('decorator')?>" />
</head>
<body>

<div id=container>

<div id=nav>
    <?php include("leftnav.php"); ?>
</div>
<div id=content>
    <?= $content ?>
</div>
<br clear="both" />
<p><?=@$page->get('footer')?>&nbsp;</p>

<?php if (!$robot) { ?>
<div id=controls style="display: none">
<?= alink('?a=edit','<u>e</u>dit', 'accesskey=e') ?>
<?= alink('?a=edit&ea=info','<u>i</u>nfo', 'accesskey=i') ?>
</div>
<?php } ?>

<div id=extra1></div>
<div id=extra2></div>
<div id=extra3></div>
<div id=extra4></div>

</div> <!-- end container -->

</body>
</html>
